@@ -32,12 +32,15 @@ from __future__ import annotations
 
 import json
 import os
+from typing import TYPE_CHECKING
 
 import google.auth.transport
-import google.oauth2
 from google.auth import credentials as google_auth_credentials, environment_vars, exceptions
 from google.oauth2 import credentials as oauth2_credentials, service_account
 
+if TYPE_CHECKING:
+    import google.oauth2
+
 # Valid types accepted for file-based credentials.
 # They are taken  from "google.auth._default" and since they are all "protected" and the imports might
 # change any time and fail the whole Google provider functionality - we should inline them
