@@ -14,8 +14,9 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
-from typing import TYPE_CHECKING, Dict, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
@@ -27,26 +28,20 @@ if TYPE_CHECKING:
 
 class CloudFirestoreExportDatabaseOperator(BaseOperator):
     """
-    Exports a copy of all or a subset of documents from Google Cloud Firestore to another storage system,
-    such as Google Cloud Storage.
+    Export documents from Google Cloud Firestore to another storage system, such as Google Cloud Storage.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:CloudFirestoreExportDatabaseOperator`
 
     :param database_id: The Database ID.
-    :type database_id: str
     :param body: The request body.
         See:
         https://firebase.google.com/docs/firestore/reference/rest/v1beta1/projects.databases/exportDocuments
-    :type body: dict
     :param project_id: ID of the Google Cloud project if None then
         default project_id is used.
-    :type project_id: str
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param api_version: API version used (for example v1 or v1beta1).
-    :type api_version: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -55,7 +50,6 @@ class CloudFirestoreExportDatabaseOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -68,12 +62,12 @@ class CloudFirestoreExportDatabaseOperator(BaseOperator):
     def __init__(
         self,
         *,
-        body: Dict,
+        body: dict,
         database_id: str = "(default)",
-        project_id: Optional[str] = None,
+        project_id: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
         api_version: str = "v1",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -89,7 +83,7 @@ class CloudFirestoreExportDatabaseOperator(BaseOperator):
         if not self.body:
             raise AirflowException("The required parameter 'body' is missing")
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudFirestoreHook(
             gcp_conn_id=self.gcp_conn_id,
             api_version=self.api_version,
